@@ -1,7 +1,7 @@
 package Bencher::Scenario::RegexpPattern::Startup;
 
-our $DATE = '2016-09-14'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -39,7 +39,7 @@ Bencher::Scenario::RegexpPattern::Startup - Benchmark module startup overhead of
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::Scenario::RegexpPattern::Startup (from Perl distribution Bencher-Scenarios-RegexpPattern), released on 2016-09-14.
+This document describes version 0.003 of Bencher::Scenario::RegexpPattern::Startup (from Perl distribution Bencher-Scenarios-RegexpPattern), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -49,13 +49,17 @@ To run benchmark with default option:
 
 For more options (dump scenario, list/include/exclude/add participants, list/include/exclude/add datasets, etc), see L<bencher> or run C<bencher --help>.
 
+=head1 DESCRIPTION
+
+Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+
 =head1 BENCHMARKED MODULES
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Regexp::Pattern> 0.1.2
+L<Regexp::Pattern> 0.1.4
 
-L<Regexp::Pattern::RegexpCommon> 0.001
+L<Regexp::Pattern::RegexpCommon> 0.002
 
 L<Regexp::Pattern::YouTube> 0.002
 
@@ -85,23 +89,22 @@ L<Regexp::Pattern::YouTube>
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
 Benchmark with default options (C<< bencher -m RegexpPattern::Startup >>):
 
  #table1#
- +-------------------------------+-----------+------------------------+------------+-----------+---------+
- | participant                   | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors   | samples |
- +-------------------------------+-----------+------------------------+------------+-----------+---------+
- | Regexp::Pattern::RegexpCommon |       9   |                    4   |        1   |   0.00013 |      20 |
- | Regexp::Pattern               |       7   |                    2   |        1   | 8.1e-05   |      21 |
- | perl -e1 (baseline)           |       5   |                    0   |        2   | 6.3e-05   |      21 |
- | Regexp::Pattern::YouTube      |       4.6 |                   -0.4 |        1.9 | 3.2e-05   |      20 |
- +-------------------------------+-----------+------------------------+------------+-----------+---------+
+ +-------------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | participant                   | proc_private_dirty_size (kB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
+ +-------------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | Regexp::Pattern::RegexpCommon | 844                          | 4.1                | 16             |       7.2 |      2.5               |        1   | 2.8e-05 |      20 |
+ | Regexp::Pattern               | 864                          | 4.2                | 16             |       6.3 |      1.6               |        1.1 | 9.8e-06 |      20 |
+ | Regexp::Pattern::YouTube      | 844                          | 4.1                | 16             |       5.1 |      0.399999999999999 |        1.4 |   1e-05 |      20 |
+ | perl -e1 (baseline)           | 952                          | 4.2                | 16             |       4.7 |      0                 |        1.5 | 2.2e-05 |      20 |
+ +-------------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 
-=head1 DESCRIPTION
 
-Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
 
 =head1 HOMEPAGE
 
@@ -125,7 +128,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
